span_complexity

Function span_complexity 

pub fn span_complexity(
    tokens: &[Token],
    format: &str,
    start: u32,
    end: u32,
) -> u64
The complexity of the code from byte start to byte end of a file with these tokens, such as one function: one path plus one per branch in it. The branches of a function nested in the span count too. 0 for prose, data and markup.